# S1WaypointsOrTracklogToFeatures.py
# Author: Micah Babinski and Paul Ferro
# Date: June 22, 2020, updated August 23, 2020
# Description: Reads the waypoint or track log json file created by s1 as a python dictionary
# Loads the key properties from the json file into a properly-formatted dictionary
# Converts the dictionary into a feature class using arcpy.JSONToFeatures_conversion
# python dictionary structure for successful conversion:
##myDict = {
##    "fields": [list],
##    "geometryType": str,
##    "hasM": bool,
##    "hasZ": bool,
##    "hasAttachments": bool,
##    "isDataVersioned": bool,
##    "objectIdField": str,
##    "spatialReference": {dict},
##    "features": [list]}

# import required modules
import arcpy, json, os

arcpy.env.overwriteOutput = True

# get input parameters

inputJsonFile = arcpy.GetParameterAsText(0)
outputWorkspace = arcpy.GetParameterAsText(1)
outputFeatureClassName = arcpy.GetParameterAsText(2)

# validate output name
#outputFeatureClassName = arcpy.ValidateTableName(outputFeatureClassName, outputWorkspace)

# open target file
#arcpy.AddMessage("Opening JSON file.")
with open(inputJsonFile, "r") as read_file:
    s1json = json.load(read_file)

# add necessary elements to new dictionary
#arcpy.AddMessage("Retrieving JSON properties to formatted dictionary.")
myDict = {}
myDict["fields"] = s1json["layers"][0]["layerDefinition"]["fields"]


myDict["geometryType"] = s1json["layers"][0]["layerDefinition"]["geometryType"]
myDict["hasM"] = s1json["layers"][0]["layerDefinition"]["hasM"]
myDict["hasZ"] = s1json["layers"][0]["layerDefinition"]["hasZ"]
myDict["hasAttachments"] = s1json["layers"][0]["layerDefinition"]["hasAttachments"]
myDict["isDataVersioned"] = s1json["layers"][0]["layerDefinition"]["isDataVersioned"]
try:
    myDict["objectIdField"] = s1json["layers"][0]["layerDefinition"]["objectIdField"]
except:
    arcpy.AddWarning("No objectIdField found")
myDict["spatialReference"] = s1json["layers"][0]["layerDefinition"]["spatialReference"]
myDict["features"] = s1json["layers"][0]["featureSet"]["features"]

count = 0 
for k in myDict["features"]:
    #print(myDict["features"][count]["attributes"]["Description"])
    #print((myDict["features"][count]["attributes"]["Description"][:250]))
    print(count)
    try:
        myDict["features"][count]["attributes"]["Description"] = (myDict["features"][count]["attributes"]["Description"][:250])
    except:
        arcpy.AddWarning("Exception found; Description field was not truncated.")
    count += 1


# convert back to json
#arcpy.AddMessage("Converting dictionary back to JSON.")

with open(os.path.join(arcpy.env.scratchFolder, "new_json.json"), "w") as write_file:
    json.dump(myDict, write_file)

# convert to feature class
#arcpy.AddMessage("Creating output feature class.")
outputPath = os.path.join(outputWorkspace, outputFeatureClassName)
arcpy.JSONToFeatures_conversion(write_file.name, outputPath)

# clean up
arcpy.AddMessage("Cleaning up.")
del myDict, s1json
os.remove(write_file.name)







