# addS1AutoPopulateFields.py
# Author: Micah Babinski
# Date: 9/13/2017
# Description: Adds auto-populatable fields to datasets
# Modifications:
# 3/25/2020: Added laser range finder fields (with inspiration from https://www.youtube.com/watch?v=xxtxn3H1g60)

# import required modules
import os
import arcpy
import sys
import time

# get user parameters
inputLayers = arcpy.GetParameter(0)
addFields = arcpy.GetParameter(1)

# define a function to print statements
def Echo(message):
    print(message)
    arcpy.AddMessage(message)


# define a function to determine whether or not a field exists
def FieldExists(table, fieldName):
    """
    """
    f = arcpy.ListFields(table, "{}".format(fieldName))
    if len(f) > 0:
        return True
    else:
        return False

# create the dictionary of field info
fieldInfo = {"Estimated Accuracy (feet)": ("Accuracy_FT", "DOUBLE", "#", "#", "#", "Estimated Accuracy (feet)"),
                 "Estimated Accuracy (meters)": ("Accuracy_M", "DOUBLE", "#", "#", "#", "Estimated Accuracy (meters)"),
                 "Coordinate Source": ("COORD_SRC", "TEXT", "#", "#", 7, "Coordinate Source"),
                 "Point X (Longitutde)": ("POINT_X", "DOUBLE", "#", "#", "#", "Point X (Longitutde)"),
                 "Point Y (Latitude)": ("POINT_Y", "DOUBLE", "#", "#", "#", "Point Y (Latitude"),
                 "GIS Miles": ("GIS_Miles", "DOUBLE", "#", "#", "#", "GIS Miles"),
                 "GIS Acres": ("GIS_Acres", "DOUBLE", "#", "#", "#", "GIS Acres"),
                 "Date": ("Date_", "DATE", "#", "#", "#", "Date"),
                 "Number of Satellites": ("ESRIGNSS_NUMSATS", "SHORT", "#", "#", "#", "Number of Satellites"),
                 "Slope distance": ("SLOPE_DISTANCE", "DOUBLE", "#", "#", "#", "Slope distance"),
                 "Horizontal distance": ("HORIZONTAL_DISTANCE", "DOUBLE", "#", "#", "#", "Horizontal distance"),
                 "Vertical distance": ("VERTICAL_DISTANCE", "DOUBLE", "#", "#", "#", "Vertical distance"),
                 "Azimuth": ("AZIMUTH", "DOUBLE", "#", "#", "#", "Azimuth"),
                 "Inclination": ("INCLINATION", "DOUBLE", "#", "#", "#", "Inclination"),
                 "Height": ("HEIGHT", "DOUBLE", "#", "#", "#", "Height"),
                 "Percent Slope": ("SLOPE_PERCENT", "DOUBLE", "#", "#", "#", "Percent Slope")
             }

# add the fields
for item in inputLayers:
    if arcpy.Describe(item).dataType == "FeatureClass" and not arcpy.TestSchemaLock(item):
        Echo("Cannot acquire schema lock on {}! Skipping that one.".format(item))
        continue
    if arcpy.Describe(item).dataType == "FeatureLayer" and not arcpy.TestSchemaLock(arcpy.Describe(item).catalogPath):
        Echo("Cannot acquire schema lock on {}! Skipping that one.".format(item))
        continue
    Echo("\nAdding fields for {}.".format(item))
    for field in addFields:
        # get the field properties
        fname = fieldInfo[field][0]
        ftype = fieldInfo[field][1]
        length = fieldInfo[field][4]
        alias = fieldInfo[field][5]
        if FieldExists(item, fname):
            Echo("\t{} already exists. Skipping that one.".format(alias))
        else:
            Echo("\t{}".format(field))
            arcpy.AddField_management(item, fname, ftype, "#", "#", length, alias)
